@@ -1,5 +1,55 @@
 JAGSgen.ordmultiNormal <-
 function (X, Z, n.cut, l2_hyper, conv_speedup){
+if (is.null(Z)){
+  num_l1_v <- ncol(X)
+  inits <- new.env() # store initial values for BUGS model
+  monitorl1.parameters <- character()  # store monitors for level 1 parameters, which will be used in the computation of sum of squares
+  monitorl2.parameters <- NULL # store monitors for level 2 parameters
+  ### generate the code for BUGS model
+  sModel <- paste("model{", sep="")
+  ### level 1 likelihood 
+  sModel <- paste(sModel,"
+  for (i in 1:n){
+    y[i] ~ dcat(P[i,])
+    P[i,1] <- 1 - Q[i,1]
+    for (i.cut in 2: n.cut) {
+      P[i,i.cut] <- Q[i,i.cut-1] - Q[i,i.cut]	  
+    }
+    P[i,n.cut+1] <- Q[i,n.cut]
+    for (i.cut in 1:n.cut){
+      logit(Q[i,i.cut]) <- z[i,i.cut]","
+      z[i,i.cut] <-")
+  for (i in 1:num_l1_v){
+    if (i != num_l1_v)
+      sModel <- paste(sModel,"beta",i,"*","X[i,",i,"]+",sep="")
+    else
+      sModel <- paste(sModel,"beta",i,"*","X[i,",i,"]",sep="")
+    monitorl1.parameters<-c(monitorl1.parameters, paste("beta",i,sep=""))
+  }
+  sModel <- paste(sModel,"-cutp[i.cut]*(1-equals(i.cut,1))
+    }",sep="")
+  sModel <- paste(sModel,"
+  }",sep="")
+  for (j in 1:num_l1_v){
+    sModel <- paste(sModel,"
+  beta",j,"~dnorm(0,",l2_hyper[3],")",sep="")
+    s<-paste("inits$","beta",j,"<-rnorm(1)",sep="")
+    eval(parse(text=s))
+  }
+  sModel <- paste(sModel,"
+  for (i.cut in 1: n.cut) {
+    cutp0[i.cut] ~ dnorm(0,tau.cut)
+  }
+  tau.cut ~ dunif(0,",l2_hyper[4],")
+  cutp[1:n.cut] <- sort(cutp0)",sep="")
+  
+  sModel<- paste(sModel,"
+}")
+  inits$cutp0=c(0,sort(runif(n.cut-1,0,6)))
+  monitor.cutp <- character()
+  for (i in 2:n.cut)
+    monitor.cutp <-c(monitor.cutp, paste('cutp[',i,']',sep=""))
+}else{
   num_l1_v <- ncol(X)
   num_l2_v <- ncol(Z)
   num_id <- nrow(Z)
@@ -110,6 +160,7 @@ function (X, Z, n.cut, l2_hyper, conv_speedup){
   monitor.cutp <- character()
   for (i in 2:n.cut)
     monitor.cutp <-c(monitor.cutp, paste('cutp[',i,']',sep=""))
+}
   sol.inits <- dump.format(as.list(inits))
   results <- list(inits = sol.inits, monitorl1.parameters = monitorl1.parameters, 
                   monitorl2.parameters = monitorl2.parameters, monitor.cutp = monitor.cutp, sModel = sModel)
